<?php

namespace Drupal\social_auth_strava\Plugin\Network;

use Drupal\Core\Url;
use Drupal\social_auth\Plugin\Network\NetworkBase;
use Strava\API\OAuth;
use Drupal\social_api\SocialApiException;

/**
 * Defines Social Auth Strava Network Plugin.
 *
 * @Network(
 *   id = "social_auth_strava",
 *   social_network = "Strava",
 *   type = "social_auth",
 *   handlers = {
 *      "settings": {
 *          "class": "\Drupal\social_auth_strava\Settings\StravaAuthSettings",
 *          "config_id": "social_auth_strava.settings"
 *      }
 *   }
 * )
 */
class StravaAuth extends NetworkBase {

  /**
   * {@inheritdoc}
   */
  public function initSdk() {
    $class_name = 'Strava\API\OAuth';
    if (!class_exists($class_name)) {
      throw new SocialApiException(sprintf('The PHP SDK for Strava could not be found. Class: %s.', $class_name));
    }

    /** @var \Drupal\social_auth_strava\Settings\StravaAuthSettingsInterface $settings */
    $settings = $this->settings;

    $redirect_uri = Url::fromRoute('social_auth_strava.callback')
      ->setAbsolute()
      ->toString();

    $options = [
      'clientId' => $settings->getClientId(),
      'clientSecret' => $settings->getClientSecret(),
      'redirectUri' => $redirect_uri,
    ];

    return new OAuth($options);
  }

}
