<?php

namespace Drupal\social_auth_strava;

use Drupal\Core\Config\ConfigFactory;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\social_auth\AuthManager\OAuth2Manager;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Manages the authentication requests.
 */
class StravaAuthManager extends OAuth2Manager {

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactory $config_factory, LoggerChannelFactoryInterface $logger_factory, RequestStack $request_stack) {
    parent::__construct(
      $config_factory->get('social_auth_strava.settings'),
      $logger_factory,
      $request_stack->getCurrentRequest()
    );
  }

  /**
   * {@inheritdoc}
   */
  public function authenticate() {
    $this->setAccessToken(
      $this->client->getAccessToken('authorization_code', ['code' => $this->request->get('code')])
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getUserInfo() {
    if (!$this->user) {
      $values = $this->accessToken->getValues();
      // Email is no longer available in Strava API,
      // let's provide default value.
      if (empty($values['athlete']['email'])) {
        $values['athlete']['email'] = NULL;
      }
      $response = (object) $values['athlete'];
      $this->user = $this->client->userDetails($response);
    }

    return $this->user;
  }

  /**
   * {@inheritdoc}
   */
  public function requestEndPoint($method, $path, $domain = NULL, array $options = []) {
    // Not applicable.
    return NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getAuthorizationUrl() {
    return $this->client->getAuthorizationUrl(['scope' => ['read_all']]);
  }

  /**
   * {@inheritdoc}
   */
  public function getState() {
    return $this->client->getState();
  }

}
